@@ -40,6 +40,7 @@
 #include <libecal/libecal.h>
 #include <libsoup/soup-misc.h>
 
+#include "server/e-ews-calendar-utils.h"
 #include "server/e-ews-connection.h"
 #include "server/e-ews-message.h"
 #include "server/e-ews-item-change.h"
@@ -336,49 +337,6 @@ ews_set_alarm (ESoapMessage *msg,
 
 }
 
-void
-ewscal_set_time (ESoapMessage *msg,
-                 const gchar *name,
-                 icaltimetype *t,
-                 gboolean with_timezone)
-{
-	gchar *str;
-	gchar *tz_ident = NULL;
-
-	if (with_timezone) {
-		if (t->is_utc || !t->zone || t->zone == icaltimezone_get_utc_timezone ()) {
-			tz_ident = g_strdup ("Z");
-		} else {
-			gint offset, is_daylight, hrs, mins;
-
-			offset = icaltimezone_get_utc_offset (
-				icaltimezone_get_utc_timezone (), t, &is_daylight);
-
-			offset = offset * (-1);
-			hrs = offset / 60;
-			mins = offset % 60;
-
-			if (hrs < 0)
-				hrs *= -1;
-			if (mins < 0)
-				mins *= -1;
-
-			tz_ident = g_strdup_printf ("%s%02d:%02d", offset > 0 ? "+" : "-", hrs, mins);
-		}
-	}
-
-	str = g_strdup_printf (
-		"%04d-%02d-%02dT%02d:%02d:%02d%s",
-		t->year, t->month, t->day,
-		t->hour, t->minute, t->second,
-		tz_ident ? tz_ident : "");
-
-	e_ews_message_write_string_parameter (msg, name, NULL, str);
-
-	g_free (tz_ident);
-	g_free (str);
-}
-
 static void
 ewscal_set_date (ESoapMessage *msg,
                  const gchar *name,
@@ -711,136 +669,6 @@ ewscal_set_meeting_timezone (ESoapMessage *msg,
 	e_soap_message_end_element (msg); /* "MeetingTimeZone" */
 }
 
-static void
-ewscal_add_availability_rrule (ESoapMessage *msg,
-                               icalproperty *prop)
-{
-	struct icalrecurrencetype recur = icalproperty_get_rrule (prop);
-	gchar buffer[16];
-	gint dayorder;
-
-	dayorder = icalrecurrencetype_day_position (recur.by_day[0]);
-	dayorder = dayorder % 5;
-	if (dayorder < 0)
-		dayorder += 5;
-	dayorder += 1;
-
-	/* expected value is 1..5, inclusive */
-	snprintf (buffer, 16, "%d", dayorder);
-	e_ews_message_write_string_parameter (msg, "DayOrder", NULL, buffer);
-
-	snprintf (buffer, 16, "%d", recur.by_month[0]);
-	e_ews_message_write_string_parameter (msg, "Month", NULL, buffer);
-
-	e_ews_message_write_string_parameter (msg, "DayOfWeek", NULL, number_to_weekday (icalrecurrencetype_day_day_of_week (recur.by_day[0])));
-}
-
-static void
-ewscal_add_availability_default_timechange (ESoapMessage *msg)
-{
-
-	e_soap_message_start_element (msg, "StandardTime", NULL, NULL);
-	e_ews_message_write_string_parameter (msg, "Bias", NULL, "0");
-	e_ews_message_write_string_parameter (msg, "Time", NULL, "00:00:00");
-	e_ews_message_write_string_parameter (msg, "DayOrder", NULL, "0");
-	e_ews_message_write_string_parameter (msg, "Month", NULL, "0");
-	e_ews_message_write_string_parameter (msg, "DayOfWeek", NULL, "Sunday");
-	e_soap_message_end_element (msg);
-
-	e_soap_message_start_element (msg, "DaylightTime", NULL, NULL);
-	e_ews_message_write_string_parameter (msg, "Bias", NULL, "0");
-	e_ews_message_write_string_parameter (msg, "Time", NULL, "00:00:00");
-	e_ews_message_write_string_parameter (msg, "DayOrder", NULL, "0");
-	e_ews_message_write_string_parameter (msg, "Month", NULL, "0");
-	e_ews_message_write_string_parameter (msg, "DayOfWeek", NULL, "Sunday");
-	e_soap_message_end_element (msg);
-}
-
-static void
-ewscal_add_availability_timechange (ESoapMessage *msg,
-                                    icalcomponent *comp,
-                                    gint baseoffs)
-{
-	gchar buffer[16];
-	icalproperty *prop;
-	struct icaltimetype dtstart;
-	gint utcoffs;
-
-	/* Calculate zone Offset from BaseOffset */
-	prop = icalcomponent_get_first_property (comp, ICAL_TZOFFSETTO_PROPERTY);
-	if (prop) {
-		utcoffs = -icalproperty_get_tzoffsetto (prop) / 60;
-		utcoffs -= baseoffs;
-		snprintf (buffer, 16, "%d", utcoffs);
-		e_ews_message_write_string_parameter (msg, "Bias", NULL, buffer);
-	}
-
-	prop = icalcomponent_get_first_property (comp, ICAL_DTSTART_PROPERTY);
-	if (prop) {
-		dtstart = icalproperty_get_dtstart (prop);
-		snprintf (buffer, 16, "%02d:%02d:%02d", dtstart.hour, dtstart.minute, dtstart.second);
-		e_ews_message_write_string_parameter (msg, "Time", NULL, buffer);
-	}
-
-	prop = icalcomponent_get_first_property (comp, ICAL_RRULE_PROPERTY);
-	if (prop)
-		ewscal_add_availability_rrule (msg, prop);
-}
-
-void
-ewscal_set_availability_timezone (ESoapMessage *msg,
-                                  icaltimezone *icaltz)
-{
-	icalcomponent *comp;
-	icalproperty *prop;
-	icalcomponent *xstd, *xdaylight;
-	gint std_utcoffs;
-	gchar *offset;
-
-	if (!icaltz)
-		return;
-
-	comp = icaltimezone_get_component (icaltz);
-
-	xstd = icalcomponent_get_first_component (comp, ICAL_XSTANDARD_COMPONENT);
-	xdaylight = icalcomponent_get_first_component (comp, ICAL_XDAYLIGHT_COMPONENT);
-
-	/*TimeZone is the root element of GetUserAvailabilityRequest*/
-	e_soap_message_start_element (msg, "TimeZone", NULL, NULL);
-
-	/* Fetch the timezone offsets for the standard (or only) zone.
-	 * Negate it, because Exchange does it backwards */
-	if (xstd) {
-		prop = icalcomponent_get_first_property (xstd, ICAL_TZOFFSETTO_PROPERTY);
-		std_utcoffs = -icalproperty_get_tzoffsetto (prop) / 60;
-	} else
-		std_utcoffs = 0;
-
-	/* This is the overall BaseOffset tag, which the Standard and Daylight
-	 * zones are offset from. It's redundant, but Exchange always sets it
-	 * to the offset of the Standard zone, and the Offset in the Standard
-	 * zone to zero. So try to avoid problems by doing the same. */
-	offset = g_strdup_printf ("%d", std_utcoffs);
-	e_ews_message_write_string_parameter (msg, "Bias", NULL, offset);
-	g_free (offset);
-
-	if (xdaylight) {
-		/* Standard */
-		e_soap_message_start_element (msg, "StandardTime", NULL, NULL);
-		ewscal_add_availability_timechange (msg, xstd, std_utcoffs);
-		e_soap_message_end_element (msg); /* "StandardTime" */
-
-		/* DayLight */
-		e_soap_message_start_element (msg, "DaylightTime", NULL, NULL);
-		ewscal_add_availability_timechange (msg, xdaylight, std_utcoffs);
-		e_soap_message_end_element (msg); /* "DaylightTime" */
-	} else
-		/* Set default values*/
-		ewscal_add_availability_default_timechange (msg);
-
-	e_soap_message_end_element (msg); /* "TimeZone" */
-}
-
 void
 ewscal_set_reccurence (ESoapMessage *msg,
                        icalproperty *rrule,
@@ -1037,36 +865,6 @@ ewscal_set_reccurence_exceptions (ESoapMessage *msg,
 	e_soap_message_end_element (msg); /* "DeletedOccurrences" */
 }
 
-void
-ewscal_get_attach_differences (const GSList *original,
-                               const GSList *modified,
-                               GSList **removed,
-                               GSList **added)
-{
-	gboolean flag;
-	GSList *i, *i_next, *j, *j_next, *original_copy, *modified_copy;
-	original_copy = g_slist_copy ((GSList *) original);
-	modified_copy = g_slist_copy ((GSList *) modified);
-
-	for (j = modified_copy; j; j = j_next) {
-		j_next = j->next;
-
-		for (i = original_copy, flag = FALSE; !flag && i; i = i_next) {
-			i_next = i->next;
-
-			if (g_strcmp0 (j->data, i->data) == 0) {
-				/* Remove from the lists attachments that are on both */
-				original_copy = g_slist_delete_link (original_copy, i);
-				modified_copy = g_slist_delete_link (modified_copy, j);
-				flag = TRUE;
-			}
-		}
-	}
-
-	*removed = original_copy;
-	*added = modified_copy;
-}
-
 /*
  * get meeting organizer e-mail address
  */
@@ -1266,7 +1064,7 @@ convert_vevent_calcomp_to_xml (ESoapMessage *msg,
 	const gchar *ical_location_start, *ical_location_end, *value;
 	const gchar *msdn_location_start, *msdn_location_end;
 
-	e_cal_component_set_icalcomponent (comp, icalcomp);
+	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));
 
 	/* FORMAT OF A SAMPLE SOAP MESSAGE: http://msdn.microsoft.com/en-us/library/aa564690.aspx */
 
@@ -1319,8 +1117,8 @@ convert_vevent_calcomp_to_xml (ESoapMessage *msg,
 			ical_location_end);
 	}
 
-	ewscal_set_time (msg, "Start", &dtstart, FALSE);
-	ewscal_set_time (msg, "End", &dtend, FALSE);
+	e_ews_cal_utils_set_time (msg, "Start", &dtstart, FALSE);
+	e_ews_cal_utils_set_time (msg, "End", &dtend, FALSE);
 	/* We have to do the time zone(s) later, or the server rejects the request */
 
 	/* All day event ? */
@@ -1396,6 +1194,8 @@ convert_vevent_calcomp_to_xml (ESoapMessage *msg,
 	}
 
 	e_soap_message_end_element (msg); /* "CalendarItem" */
+
+	g_object_unref (comp);
 }
 
 static void
@@ -1422,7 +1222,7 @@ convert_vtodo_calcomp_to_xml (ESoapMessage *msg,
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_DUE_PROPERTY);
 	if (prop) {
 		dt = icalproperty_get_due (prop);
-		ewscal_set_time (msg, "DueDate", &dt, TRUE);
+		e_ews_cal_utils_set_time (msg, "DueDate", &dt, TRUE);
 	}
 
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_PERCENTCOMPLETE_PROPERTY);
@@ -1435,7 +1235,7 @@ convert_vtodo_calcomp_to_xml (ESoapMessage *msg,
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_DTSTART_PROPERTY);
 	if (prop) {
 		dt = icalproperty_get_dtstart (prop);
-		ewscal_set_time (msg, "StartDate", &dt, TRUE);
+		e_ews_cal_utils_set_time (msg, "StartDate", &dt, TRUE);
 	}
 
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_STATUS_PROPERTY);
@@ -1749,13 +1549,13 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 
 	if (dt_start_changed) {
 		e_ews_message_start_set_item_field (msg, "Start", "calendar","CalendarItem");
-		ewscal_set_time (msg, "Start", &dtstart, FALSE);
+		e_ews_cal_utils_set_time (msg, "Start", &dtstart, FALSE);
 		e_ews_message_end_set_item_field (msg);
 	}
 
 	if (dt_end_changed) {
 		e_ews_message_start_set_item_field (msg, "End", "calendar", "CalendarItem");
-		ewscal_set_time (msg, "End", &dtend, FALSE);
+		e_ews_cal_utils_set_time (msg, "End", &dtend, FALSE);
 		e_ews_message_end_set_item_field (msg);
 	}
 
@@ -1913,7 +1713,7 @@ convert_vtodo_component_to_updatexml (ESoapMessage *msg,
 	if (prop) {
 		dt = icalproperty_get_due (prop);
 		e_ews_message_start_set_item_field (msg, "DueDate", "task", "Task");
-		ewscal_set_time (msg, "DueDate", &dt, TRUE);
+		e_ews_cal_utils_set_time (msg, "DueDate", &dt, TRUE);
 		e_ews_message_end_set_item_field (msg);
 	} else {
 		e_ews_message_add_delete_item_field (msg, "DueDate", "task");
@@ -1932,7 +1732,7 @@ convert_vtodo_component_to_updatexml (ESoapMessage *msg,
 	if (prop) {
 		dt = icalproperty_get_dtstart (prop);
 		e_ews_message_start_set_item_field (msg, "StartDate", "task", "Task");
-		ewscal_set_time (msg, "StartDate", &dt, TRUE);
+		e_ews_cal_utils_set_time (msg, "StartDate", &dt, TRUE);
 		e_ews_message_end_set_item_field (msg);
 	} else {
 		e_ews_message_add_delete_item_field (msg, "StartDate", "task");
@@ -2070,6 +1870,7 @@ e_cal_backend_ews_rid_to_index (icaltimezone *timezone,
 		g_propagate_error (
 			error, EDC_ERROR_EX (OtherError,
 			"Invalid occurrence ID"));
+		index = 0;
 	}
 
 	return index;
@@ -2097,49 +1898,6 @@ e_cal_backend_ews_clear_reminder_is_set (ESoapMessage *msg,
 	e_ews_message_end_item_change (msg);
 }
 
-void
-e_cal_backend_ews_prepare_free_busy_request (ESoapMessage *msg,
-					     gpointer user_data)
-{
-	EwsCalendarConvertData *convert_data = user_data;
-	GSList *addr;
-	icaltimetype t_start, t_end;
-	icaltimezone *utc_zone = icaltimezone_get_utc_timezone ();
-
-	ewscal_set_availability_timezone (msg, utc_zone);
-
-	e_soap_message_start_element (msg, "MailboxDataArray", "messages", NULL);
-
-	for (addr = convert_data->users; addr; addr = addr->next) {
-		e_soap_message_start_element (msg, "MailboxData", NULL, NULL);
-
-		e_soap_message_start_element (msg, "Email", NULL, NULL);
-		e_ews_message_write_string_parameter (msg, "Address", NULL, addr->data);
-		e_soap_message_end_element (msg); /* "Email" */
-
-		e_ews_message_write_string_parameter (msg, "AttendeeType", NULL, "Required");
-		e_ews_message_write_string_parameter (msg, "ExcludeConflicts", NULL, "false");
-
-		e_soap_message_end_element (msg); /* "MailboxData" */
-	}
-
-	e_soap_message_end_element (msg); /* "MailboxDataArray" */
-
-	e_soap_message_start_element (msg, "FreeBusyViewOptions", NULL, NULL);
-
-	e_soap_message_start_element (msg, "TimeWindow", NULL, NULL);
-	t_start = icaltime_from_timet_with_zone (convert_data->start, 0, utc_zone);
-	t_end = icaltime_from_timet_with_zone (convert_data->end, 0, utc_zone);
-	ewscal_set_time (msg, "StartTime", &t_start, FALSE);
-	ewscal_set_time (msg, "EndTime", &t_end, FALSE);
-	e_soap_message_end_element (msg); /* "TimeWindow" */
-
-	e_ews_message_write_string_parameter (msg, "MergedFreeBusyIntervalInMinutes", NULL, "60");
-	e_ews_message_write_string_parameter (msg, "RequestedView", NULL, "DetailedMerged");
-
-	e_soap_message_end_element (msg); /* "FreeBusyViewOptions" */
-}
-
 void
 e_cal_backend_ews_prepare_set_free_busy_status (ESoapMessage *msg,
 						gpointer user_data)
