@@ -32,6 +32,7 @@
 #include "e-mail-config-ews-ooo-page.h"
 #include "e-mail-config-ews-folder-sizes-page.h"
 #include "e-ews-ooo-notificator.h"
+#include "e-ews-config-lookup.h"
 
 #include "e-ews-config-ui-extension.h"
 #include "server/e-source-ews-folder.h"
@@ -57,6 +58,7 @@ e_module_load (GTypeModule *type_module)
 	e_mail_config_ews_delegates_page_type_register (type_module);
 	e_mail_config_ews_ooo_page_type_register (type_module);
 	e_mail_config_ews_folder_sizes_page_type_register (type_module);
+	e_ews_config_lookup_type_register (type_module);
 	e_ews_config_ui_extension_type_register (type_module);
 	e_ews_ooo_notificator_type_register (type_module);
 
